(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    576569,      12313]
NotebookOptionsPosition[    575017,      12283]
NotebookOutlinePosition[    575414,      12299]
CellTagsIndexPosition[    575371,      12296]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"25233f08-81b2-4ad1-a017-7e072f01156f"],

Cell[CellGroupData[{

Cell["Chapter 3, Section 3.7.1", "Section",
 CellChangeTimes->{{3.856170518477427*^9, 
  3.8561705229195843`*^9}},ExpressionUUID->"80a4361f-9f08-44df-be05-\
306220eb6add"],

Cell["\<\
The stability of the L1 point can be illustrated by plotting the pairs of \
eigenvalues on an Argand diagram for a given value of the mass \[Mu].  A \
Lagrange equilibrium point will be linearly unstable to small displacements \
if any of the four eigenvalues have a positive real part as this will \
guarantee motion away from the equilibrium point.  In the case of the L1 \
point the four eigenvalues always occur in pairs of the form +/- a and +/-ib \
for all values of the mass \[Mu], and so there will always be one real, \
positive root meaning that the point is linearly unstable.  A similar \
analysis can be done for the L2 and L3 points and the outcome is the same  \
\[Dash] all three of the colinear point, L1, L2 and L3 are linearly unstable \
to small displacements.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.855915078325811*^9, 3.8559151502800093`*^9}, {
  3.855915371244178*^9, 3.855915372983162*^9}, {3.8559156721421623`*^9, 
  3.855915788394665*^9}, {3.8561705365368834`*^9, 3.8561707033679657`*^9}, {
  3.856170739906918*^9, 3.8561709098999166`*^9}, {3.856170949215435*^9, 
  3.8561711054044847`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2e7f8c0e-0e2f-4746-bf91-b282388e0bbe"],

Cell[TextData[{
 "To illustrate the behaviour of the roots, we first define a function ",
 StyleBox["StabilityL1",
  FontWeight->"Bold"],
 " to calculate the four roots of the characteristic equation for a given \
mass \[Mu]."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.855915078325811*^9, 3.8559151502800093`*^9}, {
  3.855915371244178*^9, 3.855915372983162*^9}, {3.8559156721421623`*^9, 
  3.855915788394665*^9}, {3.8561705365368834`*^9, 3.8561707033679657`*^9}, {
  3.856170739906918*^9, 3.8561709098999166`*^9}, {3.856170949215435*^9, 
  3.856171179717293*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2f2ac88a-1ab0-4f6c-ac9e-3391e980f0dd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"StabilityL1", "[", "mu_", "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"alpha", ",", "r1", ",", "r2", ",", 
      RowBox[{"mu1", "=", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", 
      RowBox[{"mu2", "=", "mu"}], ",", "lageq", ",", "beta"}], "}"}], ",", 
    "\n", "    ", 
    RowBox[{
     RowBox[{"y", "=", "0"}], ";", "\n", "    ", 
     RowBox[{"alpha", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"mu", "/", 
         RowBox[{"(", 
          RowBox[{"3", "*", 
           RowBox[{"(", 
            RowBox[{"1", "-", "mu"}], ")"}]}], ")"}]}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\n", "    ", 
     RowBox[{"r20", " ", "=", " ", 
      RowBox[{"alpha", " ", "-", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "3"}], ")"}], "*", 
        RowBox[{"alpha", "^", "2"}]}], " ", "-", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "9"}], ")"}], "*", 
        RowBox[{"alpha", "^", "3"}]}]}]}], ";", "\n", "    ", 
     RowBox[{"lageq", " ", "=", " ", 
      RowBox[{
       RowBox[{"mu1", "*", 
        RowBox[{"(", 
         RowBox[{"1", "-", "r2", "-", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "r2"}], ")"}], "^", "2"}]}]}], ")"}]}], "-", 
       RowBox[{"mu2", "*", 
        RowBox[{"(", 
         RowBox[{"r2", "-", 
          RowBox[{"1", "/", 
           RowBox[{"r2", "^", "2"}]}]}], ")"}]}]}]}], ";", "\n", "    ", 
     RowBox[{"r2", " ", "=", " ", 
      RowBox[{"r2", " ", "/.", " ", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{"lageq", " ", "==", " ", "0"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"r2", ",", " ", "r20"}], "}"}]}], "]"}]}]}], ";", "\n", 
     "    ", 
     RowBox[{"r1", " ", "=", " ", 
      RowBox[{"1", " ", "-", " ", "r2"}]}], ";", "\n", "    ", 
     RowBox[{"x", " ", "=", " ", 
      RowBox[{"mu1", "-", "r2"}]}], ";", "\n", "    ", 
     RowBox[{"abar", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "mu"}], ")"}], "/", 
        RowBox[{"r1", "^", "3"}]}], " ", "+", " ", 
       RowBox[{"mu", "/", 
        RowBox[{"r2", "^", "3"}]}]}]}], ";", "\n", "    ", 
     RowBox[{"ceqq", " ", "=", " ", 
      RowBox[{
       RowBox[{"\[Lambda]", "^", "4"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "-", "abar"}], ")"}], "*", 
        RowBox[{"\[Lambda]", "^", "2"}]}], " ", "+", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "abar", "-", 
         RowBox[{"2", "*", 
          RowBox[{"abar", "^", "2"}]}]}], ")"}]}]}], ";", "\n", "    ", 
     RowBox[{"soln", " ", "=", " ", 
      RowBox[{"Chop", "[", 
       RowBox[{"\[Lambda]", " ", "/.", " ", 
        RowBox[{"NSolve", "[", 
         RowBox[{
          RowBox[{"ceqq", " ", "==", " ", "0"}], ",", " ", 
          RowBox[{"{", "\[Lambda]", "}"}]}], "]"}]}], "]"}]}], ";", "\n", 
     "soln"}]}], "\n", "]"}]}]], "Input",
 CellChangeTimes->{{3.855820996818294*^9, 3.8558209968203163`*^9}, {
   3.855824024129457*^9, 3.855824044902556*^9}, {3.855824085296891*^9, 
   3.8558240864231157`*^9}, {3.855824151144805*^9, 3.855824160248396*^9}, {
   3.8558249874373703`*^9, 3.85582502579167*^9}, {3.85616752778612*^9, 
   3.856167599890668*^9}, 3.8561676363116293`*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"f4819cb5-e1db-48c7-bd65-1da7c511f104"],

Cell["\<\
To save computation we define the plotting frame for our Argand diagram.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.855915078325811*^9, 3.8559151502800093`*^9}, {
  3.855915371244178*^9, 3.855915372983162*^9}, {3.8559156721421623`*^9, 
  3.855915788394665*^9}, {3.8561705365368834`*^9, 3.8561707033679657`*^9}, {
  3.856170739906918*^9, 3.8561709098999166`*^9}, {3.856170949215435*^9, 
  3.856171179717293*^9}, {3.8561712113553658`*^9, 3.856171227866268*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3472557a-e183-495a-a1e0-a1748157f5fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"frame", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{"AspectRatio", "->", "Automatic"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"BaseStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "24"}], ",", "Black"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "->", 
      RowBox[{"{", 
       RowBox[{"640", ",", "480"}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Real Part\>\"", ",", "\"\<Imaginary Part\>\""}], "}"}]}], 
     ",", 
     RowBox[{"FrameTicksStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"AxesStyle", "\[Rule]", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"Background", "->", "White"}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.05", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.856168584010584*^9, 3.856168616076112*^9}, {
  3.856169897129092*^9, 3.85616993135411*^9}, {3.85617001321282*^9, 
  3.856170015730172*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"96ce5dec-ee45-4af3-adb1-ac8f52cfe628"],

Cell["\<\
Now we construct a list of plots of the Argand diagram for decreasing values \
of the mass \[Mu]. \
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.855915078325811*^9, 3.8559151502800093`*^9}, {
  3.855915371244178*^9, 3.855915372983162*^9}, {3.8559156721421623`*^9, 
  3.855915788394665*^9}, {3.8561705365368834`*^9, 3.8561707033679657`*^9}, {
  3.856170739906918*^9, 3.8561709098999166`*^9}, {3.856170949215435*^9, 
  3.856171179717293*^9}, {3.8561712113553658`*^9, 3.8561712616031017`*^9}, {
  3.856171369413595*^9, 3.856171406546379*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"becc19cb-91d4-4e47-aad4-f4aed99b14a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p", "=", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"tmu", "=", 
       RowBox[{"0.1", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"i", "-", "1"}], ")"}], "*", "0.001"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"values", "=", 
       RowBox[{"StabilityL1", "[", "tmu", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"pts", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", "#", "]"}], ",", 
            RowBox[{"Im", "[", "#", "]"}]}], "}"}], "&"}], ",", "values"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"plot", "=", 
       RowBox[{"ListPlot", "[", 
        RowBox[{"pts", ",", 
         RowBox[{"PlotStyle", "->", 
          RowBox[{"{", 
           RowBox[{"Red", ",", 
            RowBox[{"PointSize", "[", "0.05", "]"}]}], "}"}]}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"mass", "=", "\[IndentingNewLine]", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<\[Mu] = \>\"", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.8"}], ",", "3.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"ToString", "[", 
             RowBox[{"N", "[", 
              RowBox[{"tmu", ",", "4"}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.0"}], ",", "3.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], 
        "]"}]}], ";", 
      RowBox[{"Show", "[", 
       RowBox[{"{", 
        RowBox[{"frame", ",", "plot", ",", "mass"}], "}"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "91"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.85616771549551*^9, 3.856167715497677*^9}, 
   3.8561683862778893`*^9, {3.856168470054199*^9, 3.8561685360558243`*^9}, {
   3.856168701953183*^9, 3.8561688263114967`*^9}, {3.856169012081664*^9, 
   3.8561690208199463`*^9}, {3.856169216642527*^9, 3.8561692178098288`*^9}, {
   3.856169628600903*^9, 3.856169635368503*^9}, {3.8561696957376013`*^9, 
   3.856169731432715*^9}, {3.856169797516329*^9, 3.8561697980183287`*^9}, 
   3.856169879103332*^9, {3.8561700600447073`*^9, 3.8561700727629347`*^9}, {
   3.856170180949991*^9, 3.856170231794417*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"7c2f08df-700d-4397-be46-6ed23336b7c0"],

Cell["\<\
Animate the resulting plots.  Note that there is always at least one \
positive,, real root and so the L1 point is always linearly unstable.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.855915078325811*^9, 3.8559151502800093`*^9}, {
  3.855915371244178*^9, 3.855915372983162*^9}, {3.8559156721421623`*^9, 
  3.855915788394665*^9}, {3.8561705365368834`*^9, 3.8561707033679657`*^9}, {
  3.856170739906918*^9, 3.8561709098999166`*^9}, {3.856170949215435*^9, 
  3.856171179717293*^9}, {3.8561712113553658`*^9, 3.8561712616031017`*^9}, {
  3.856171369413595*^9, 3.856171448369162*^9}, {3.856171480163172*^9, 
  3.856171509456221*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"32372479-3bef-41f2-b7be-afc27e7f748c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mp", "=", 
  RowBox[{"ListAnimate", "[", "p", "]"}]}]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"b6701cce-d6c0-4fa3-b437-c088f1a8ac90"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i11$$ = 33, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i11$$ = 1}, 
     "\"max\"" :> {$CellContext`i11$$ = 91}}, Typeset`bookmarkMode$$ = "Menu",
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i11$$], 1, ""}, 1, 91, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    PaneBox[
     PanelBox[GridBox[{
        {
         ItemBox[
          ItemBox[
           TagBox[
            StyleBox[GridBox[{
               {"\<\"\"\>", 
                AnimatorBox[Dynamic[$CellContext`i11$$], {1, 91, 1},
                 AnimationRate->Automatic,
                 AnimationRunTime->109.85506343841553`,
                 AnimationTimeIndex->1.7689204792394548`,
                 
                 AppearanceElements->{
                  "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
                   "DirectionButton"},
                 AutoAction->False,
                 DisplayAllSteps->True]}
              },
              AutoDelete->False,
              
              GridBoxAlignment->{
               "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
             "ListAnimateLabel",
             StripOnInput->False],
            {"ControlArea", Top}],
           Alignment->{Automatic, Inherited},
           StripOnInput->False],
          Background->None,
          StripOnInput->False]},
        {
         ItemBox[
          TagBox[
           StyleBox[
            PaneBox[
             TagBox[
              PaneSelectorBox[{1->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.38792306774071, 0.}, {
                    0., -2.6255662167301415`}, {0., 2.6255662167301415`}, {
                    3.38792306774071, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.1\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 2->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.385064403468404, 0.}, {
                    0., -2.6237183577251955`}, {0., 2.6237183577251955`}, {
                    3.385064403468404, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.099\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 3->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3821821540850605`, 0.}, {
                    0., -2.621855503874818}, {0., 2.621855503874818}, {
                    3.3821821540850605`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.098\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 4->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3792759523137947`, 0.}, {
                    0., -2.6199774245467906`}, {0., 2.6199774245467906`}, {
                    3.379275952313795, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.097\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 5->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3763454209825046`, 0.}, {
                    0., -2.618083882924032}, {0., 2.618083882924032}, {
                    3.376345420982504, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.096\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 6->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3733901726512228`, 0.}, {
                    0., -2.616174635772349}, {0., 2.616174635772349}, {
                    3.3733901726512228`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.095\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 7->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.370409809221323, 0.}, {
                    0., -2.6142494331968864`}, {0., 2.6142494331968864`}, {
                    3.370409809221323, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.094\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 8->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.367403921525485, 0.}, {
                    0., -2.6123080183866247`}, {0., 2.6123080183866247`}, {
                    3.367403921525485, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.093\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 9->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.364372088897265, 0.}, {
                    0., -2.6103501273461793`}, {0., 2.6103501273461793`}, {
                    3.364372088897265, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.092\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 10->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3613138787190073`, 0.}, {
                    0., -2.6083754886141404`}, {0., 2.6083754886141404`}, {
                    3.3613138787190073`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.091\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 11->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.358228845946768, 0.}, {
                    0., -2.6063838229671106`}, {0., 2.6063838229671106`}, {
                    3.358228845946768, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.09\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 12->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3551165326108032`, 0.}, {
                    0., -2.604374843108553}, {0., 2.604374843108553}, {
                    3.3551165326108032`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.089\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 13->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3519764672900796`, 0.}, {
                    0., -2.6023482533414857`}, {0., 2.6023482533414857`}, {
                    3.35197646729008, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.088\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 14->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3488081645591428`, 0.}, {
                    0., -2.6003037492239907`}, {0., 2.6003037492239907`}, {
                    3.3488081645591428`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.087\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 15->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3456111244055418`, 0.}, {
                    0., -2.5982410172064223`}, {0., 2.5982410172064223`}, {
                    3.3456111244055418`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.086\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 16->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3423848316159006`, 0.}, {
                    0., -2.5961597342491207`}, {0., 2.5961597342491207`}, {
                    3.3423848316159006`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.085\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 17->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3391287551285336`, 0.}, {
                    0., -2.5940595674193405`}, {0., 2.5940595674193405`}, {
                    3.339128755128534, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.084\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 18->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3358423473503813`, 0.}, {
                    0., -2.591940173465993}, {0., 2.591940173465993}, {
                    3.3358423473503813`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.083\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 19->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3325250434358122`, 0.}, {
                    0., -2.589801198370701}, {0., 2.589801198370701}, {
                    3.3325250434358122`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.082\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 20->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3291762605247155`, 0.}, {
                    0., -2.5876422768735563`}, {0., 2.5876422768735563`}, {
                    3.3291762605247155`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.081\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 21->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3257953969369867`, 0.}, {
                    0., -2.585463031971772}, {0., 2.585463031971772}, {
                    3.3257953969369862`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.08\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 22->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3223818313203966`, 0.}, {
                    0., -2.5832630743893925`}, {0., 2.5832630743893925`}, {
                    3.3223818313203966`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.079\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 23->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3189349217484665`, 0.}, {
                    0., -2.5810420020159275`}, {0., 2.5810420020159275`}, {
                    3.3189349217484665`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.078\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 24->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.315454004764752, 0.}, {
                    0., -2.5787993993117095`}, {0., 2.5787993993117095`}, {
                    3.315454004764752, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.077\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 25->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3119383943696166`, 0.}, {
                    0., -2.576534836677528}, {0., 2.576534836677528}, {
                    3.3119383943696166`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.076\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 26->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.308387380945209, 0.}, {
                    0., -2.5742478697858826`}, {0., 2.5742478697858826`}, {
                    3.308387380945209, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.075\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 27->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.304800230113998, 0.}, {
                    0., -2.571938038870979}, {0., 2.571938038870979}, {
                    3.304800230113998, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.074\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 28->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.3011761815258107`, 0.}, {
                    0., -2.569604867974332}, {0., 2.569604867974332}, {
                    3.3011761815258107`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.073\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 29->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2975144475678277`, 0.}, {
                    0., -2.567247864142524}, {0., 2.567247864142524}, {
                    3.2975144475678277`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.072\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 30->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2938142119915064`, 0.}, {
                    0., -2.564866516573408}, {0., 2.564866516573408}, {
                    3.2938142119915064`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.071\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 31->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.290074628449818, 0.}, {
                    0., -2.5624602957066185`}, {0., 2.5624602957066185`}, {
                    3.2900746284498177`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.07\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 32->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.286294818937578, 0.}, {
                    0., -2.560028652253948}, {0., 2.560028652253948}, {
                    3.286294818937578, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.069\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 33->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2824738721269218`, 0.}, {
                    0., -2.557571016164633}, {0., 2.557571016164633}, {
                    3.2824738721269218`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.068\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 34->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2786108415892303`, 0.}, {
                    0., -2.555086795520182}, {0., 2.555086795520182}, {
                    3.2786108415892303`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.067\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 35->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2747047438939245`, 0.}, {
                    0., -2.552575375352793}, {0., 2.552575375352793}, {
                    3.2747047438939245`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.066\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 36->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2707545565736007`, 0.}, {
                    0., -2.5500361163808405`}, {0., 2.5500361163808405`}, {
                    3.2707545565736003`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.065\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 37->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2667592159438783`, 0.}, {
                    0., -2.547468353654231}, {0., 2.547468353654231}, {
                    3.2667592159438783`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.064\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 38->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2627176147651324`, 0.}, {
                    0., -2.5448713951016626`}, {0., 2.5448713951016626`}, {
                    3.2627176147651324`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.063\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 39->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.258628599731948, 0.}, {
                    0., -2.5422445199710353`}, {0., 2.5422445199710353`}, {
                    3.258628599731948, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.062\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 40->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2544909687745607`, 0.}, {
                    0., -2.5395869771532453`}, {0., 2.5395869771532453`}, {
                    3.2544909687745602`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.061\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 41->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2503034681548906`, 0.}, {
                    0., -2.5368979833786}, {0., 2.5368979833786}, {
                    3.2503034681548906`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.06\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 42->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2460647893378045`, 0.}, {
                    0., -2.5341767212738477`}, {0., 2.5341767212738477`}, {
                    3.2460647893378045`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.059\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 43->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2417735656160493`, 0.}, {
                    0., -2.5314223372664877`}, {0., 2.5314223372664877`}, {
                    3.2417735656160493`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.058\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 44->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2374283684648795`, 0.}, {
                    0., -2.528633939321492}, {0., 2.528633939321492}, {
                    3.2374283684648795`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.057\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 45->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2330277035995163`, 0.}, {
                    0., -2.5258105944938203`}, {0., 2.5258105944938203`}, {
                    3.2330277035995163`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.056\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 46->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2285700067054504`, 0.}, {
                    0., -2.522951326278151}, {0., 2.522951326278151}, {
                    3.2285700067054504`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.055\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 47->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2240536388079195`, 0.}, {
                    0., -2.5200551117349907`}, {0., 2.5200551117349907`}, {
                    3.2240536388079195`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.054\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 48->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.219476881242767, 0.}, {
                    0., -2.517120878369757}, {0., 2.517120878369757}, {
                    3.219476881242767, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.053\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 49->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.214837930186096, 0.}, {
                    0., -2.5141475007384835`}, {0., 2.5141475007384835`}, {
                    3.214837930186096, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.052\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 50->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.210134890694717, 0.}, {
                    0., -2.511133796750437}, {0., 2.511133796750437}, {
                    3.210134890694717, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.051\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 51->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.2053657702030622`, 0.}, {
                    0., -2.5080785236340146`}, {0., 2.5080785236340146`}, {
                    3.205365770203062, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.05\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 52->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.200528471415029, 0.}, {
                    0., -2.504980373527862}, {0., 2.504980373527862}, {
                    3.200528471415029, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.049\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 53->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.195620784520811, 0.}, {
                    0., -2.5018379686539176`}, {0., 2.5018379686539176`}, {
                    3.195620784520811, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.048\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 54->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.190640378659054, 0.}, {
                    0., -2.4986498560231127`}, {0., 2.4986498560231127`}, {
                    3.190640378659054, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.047\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 55->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.185584792533376, 0.}, {
                    0., -2.4954145016174523`}, {0., 2.4954145016174523`}, {
                    3.185584792533376, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.046\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 56->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.1804514240790467`, 0.}, {
                    0., -2.49213028398403}, {0., 2.49213028398403}, {
                    3.1804514240790462`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.045\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 57->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.175237519060225, 0.}, {
                    0., -2.4887954871670006`}, {0., 2.4887954871670006`}, {
                    3.175237519060225, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.044\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 58->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.169940158459914, 0.}, {
                    0., -2.485408292892276}, {0., 2.485408292892276}, {
                    3.1699401584599136`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.043\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 59->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.164556244503436, 0.}, {
                    0., -2.4819667719065164`}, {0., 2.4819667719065164`}, {
                    3.164556244503436, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.042\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 60->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.15908248513089, 0.}, {
                    0., -2.4784688743563135`}, {0., 2.4784688743563135`}, {
                    3.15908248513089, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.041\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 61->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.1535153767039206`, 0.}, {
                    0., -2.474912419074876}, {0., 2.474912419074876}, {
                    3.1535153767039206`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.04\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 62->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.147851184696317, 0.}, {
                    0., -2.471295081621385}, {0., 2.471295081621385}, {
                    3.147851184696317, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.039\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 63->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.142085922074936, 0.}, {
                    0., -2.467614380891634}, {0., 2.467614380891634}, {
                    3.142085922074936, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.038\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 64->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.1362153250258094`, 0.}, {
                    0., -2.463867664086674}, {0., 2.463867664086674}, {
                    3.1362153250258094`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.037\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 65->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.13023482561786, 0.}, {
                    0., -2.4600520897876272`}, {0., 2.4600520897876272`}, {
                    3.13023482561786, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.036\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 66->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.1241395209208394`, 0.}, {
                    0., -2.456164608838045}, {0., 2.456164608838045}, {
                    3.1241395209208394`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.035\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 67->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.1179241380016562`, 0.}, {
                    0., -2.452201942678116}, {0., 2.452201942678116}, {
                    3.1179241380016562`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.034\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 68->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.111582994109753, 0.}, {
                    0., -2.4481605587049495`}, {0., 2.4481605587049495`}, {
                    3.1115829941097526`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.033\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 69->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.1051099512222318`, 0.}, {
                    0., -2.4440366421468185`}, {0., 2.4440366421468185`}, {
                    3.1051099512222318`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.032\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 70->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.0984983639456805`, 0.}, {
                    0., -2.4398260638319997`}, {0., 2.4398260638319997`}, {
                    3.0984983639456805`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.031\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 71->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.0917410195546147`, 0.}, {
                    0., -2.43552434309897}, {0., 2.43552434309897}, {
                    3.091741019554615, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.03\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 72->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.084830068673555, 0.}, {
                    0., -2.431126604926333}, {0., 2.431126604926333}, {
                    3.084830068673555, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.029\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 73->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.0777569447641326`, 0.}, {
                    0., -2.426627530147693}, {0., 2.426627530147693}, {
                    3.0777569447641326`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.028\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 74->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.0705122701375656`, 0.}, {
                    0., -2.422021297344665}, {0., 2.422021297344665}, {
                    3.0705122701375656`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.027\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 75->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.0630857456453513`, 0.}, {
                    0., -2.41730151466125}, {0., 2.41730151466125}, {
                    3.0630857456453513`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.026\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 76->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.0554660204646744`, 0.}, {
                    0., -2.4124611393288258`}, {0., 2.4124611393288258`}, {
                    3.0554660204646744`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.025\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 77->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.0476405374304343`, 0.}, {
                    0., -2.4074923820963323`}, {0., 2.4074923820963323`}, {
                    3.0476405374304343`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.024\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 78->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.039595348089694, 0.}, {
                    0., -2.40238659297368}, {0., 2.40238659297368}, {
                    3.039595348089694, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.023\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 79->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.031314889947834, 0.}, {
                    0., -2.397134123644691}, {0., 2.397134123644691}, {
                    3.031314889947834, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.022\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 80->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.0227817160669725`, 0.}, {
                    0., -2.3917241604832795`}, {0., 2.3917241604832795`}, {
                    3.0227817160669725`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.021\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 81->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.01397616401402, 0.}, {
                    0., -2.3861445201577585`}, {0., 2.3861445201577585`}, {
                    3.01397616401402, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.02\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 82->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-3.0048759467623256`, 0.}, {
                    0., -2.3803813971018615`}, {0., 2.3803813971018615`}, {
                    3.0048759467623256`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.019\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 83->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-2.995455641956534, 0.}, {
                    0., -2.374419048316093}, {0., 2.374419048316093}, {
                    2.995455641956534, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.018\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 84->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-2.9856860470724507`, 0.}, {
                    0., -2.3682393954962566`}, {0., 2.3682393954962566`}, {
                    2.9856860470724507`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.017\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 85->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-2.9755333550478587`, 0.}, {
                    0., -2.3618215165096044`}, {0., 2.3618215165096044`}, {
                    2.9755333550478587`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.016\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 86->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-2.9649580856707183`, 0.}, {
                    0., -2.355140986365425}, {0., 2.355140986365425}, {
                    2.964958085670718, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.015\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 87->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-2.9539136786445646`, 0.}, {
                    0., -2.348169009753942}, {0., 2.348169009753942}, {
                    2.9539136786445646`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.014\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 88->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-2.9423446084115548`, 0.}, {
                    0., -2.340871259022378}, {0., 2.340871259022378}, {
                    2.9423446084115543`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.013\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 89->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-2.930183807214002, 0.}, {
                    0., -2.333206286180779}, {0., 2.333206286180779}, {
                    2.930183807214002, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.012\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 90->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-2.9173490608463055`, 0.}, {
                    0., -2.3251233024783686`}, {0., 2.3251233024783686`}, {
                    2.9173490608463055`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.011\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}], 91->
               GraphicsBox[{{}, {{}, 
                  {RGBColor[1, 0, 0], PointSize[0.05], AbsoluteThickness[1.6],
                    PointBox[{{-2.903737831611212, 0.}, {
                    0., -2.3165589900025214`}, {0., 2.3165589900025214`}, {
                    2.9037378316112123`, 0.}}]}, {{}, {}}}, 
                 {RGBColor[0, 0, 1], 
                  InsetBox["\<\"\[Mu] = \"\>", {-3.8, 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
                  InsetBox["\<\"0.01\"\>", {-3., 3.5}, NCache[
                   ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]}},
                AlignmentPoint->Center,
                AspectRatio->Automatic,
                Axes->{True, True},
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                AxesStyle->Thickness[0.004],
                Background->GrayLevel[1],
                BaseStyle->{FontFamily -> "Helvetica", FontSize -> 24, 
                  GrayLevel[0]},
                BaselinePosition->Automatic,
                ColorOutput->Automatic,
                ContentSelectable->Automatic,
                CoordinatesToolOptions:>Automatic,
                DisplayFunction->Identity,
                Epilog->{},
                FormatType:>TraditionalForm,
                Frame->{{True, True}, {True, True}},
                FrameLabel->{{
                   FormBox[
                    TagBox["\"Imaginary Part\"", HoldForm], TraditionalForm], 
                   None}, {
                   FormBox[
                    TagBox["\"Real Part\"", HoldForm], TraditionalForm], 
                   None}},
                FrameStyle->Thickness[0.004],
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                FrameTicksStyle->Thickness[0.004],
                GridLines->{None, None},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImageMargins->0.,
                ImagePadding->All,
                ImageSize->{640, 480},
                ImageSizeRaw->Automatic,
                LabelStyle->{},
                
                Method->{
                 "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                  Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "DefaultPlotStyle" -> {
                    Directive[
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], 
                    Directive[
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02],
                   "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
                  Scaled[0.05], "MessagesHead" -> ListPlot, 
                  "DownsampleWindow" -> None, "OptimizePlotMarkers" -> True, 
                  "MessagesHead" -> ListPlot, "OptimizePlotMarkers" -> True, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Identity[
                    Part[#, 1]], 
                    Identity[
                    Part[#, 2]]}& )}},
                PlotLabel->None,
                PlotRange->{{-4., 4.}, {-4., 4.}},
                PlotRangeClipping->True,
                PlotRangePadding->{{0, 0}, {0, 0}},
                PlotRegion->Automatic,
                PreserveImageOptions->Automatic,
                Prolog->{},
                RotateLabel->True,
                Ticks->{Automatic, Automatic},
                TicksStyle->{}]}, Dynamic[$CellContext`i11$$],
               Alignment->Automatic,
               BaseStyle->"ListAnimateCore",
               ImageSize->All,
               TransitionDirection->Horizontal,
               TransitionDuration->0.5,
               TransitionEffect->Automatic],
              Identity,
              Editable->True,
              Selectable->True],
             ImageMargins->10],
            Deployed->False,
            StripOnInput->False,
            ScriptLevel->0,
            GraphicsBoxOptions->{PreserveImageOptions->True},
            Graphics3DBoxOptions->{PreserveImageOptions->True}],
           Identity,
           Editable->False,
           Selectable->False],
          Alignment->{Left, Center},
          Background->GrayLevel[1],
          Frame->1,
          FrameStyle->GrayLevel[0, 0.2],
          ItemSize->Automatic,
          StripOnInput->False]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
       GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {
           Offset[0.7], {
            Offset[0.5599999999999999]}, 
           Offset[0.7]}, "Rows" -> {
           Offset[0.4], {
            Offset[0.8]}, 
           Offset[0.4]}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.856169659672908*^9, 3.856169740448262*^9, 3.8561698075045757`*^9, 
   3.856169889229477*^9, 3.8561699442648582`*^9, 3.856170027299243*^9, 
   3.8561700866273413`*^9, {3.8561702143451147`*^9, 3.8561702405182037`*^9}, 
   3.856171713394808*^9, 3.856171913925788*^9, 3.890907905587345*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"d820740f-6b82-4c67-8297-0fd4da007f2a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{"Export", "[", 
   RowBox[{"\"\<L1_Stability.mov\>\"", ",", "mp", ",", " ", 
    RowBox[{"\"\<ControlAppearance\>\"", "\[Rule]", "None"}]}], "]"}], 
  "\[IndentingNewLine]", "*)"}]], "Input",
 CellChangeTimes->{{3.8112457016793423`*^9, 3.811245710232283*^9}, {
  3.856171878383333*^9, 3.85617188646873*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"27215680-0b6f-48a0-a7ea-4c267f407ab0"]
}, Open  ]]
},
WindowSize->{963, 646},
WindowMargins->{{81, Automatic}, {Automatic, 28}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"1bb0552d-9d17-4ca8-a9d4-0a8c6af9bd0f"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"25233f08-81b2-4ad1-a017-7e072f01156f"],
Cell[CellGroupData[{
Cell[970, 32, 171, 3, 67, "Section",ExpressionUUID->"80a4361f-9f08-44df-be05-306220eb6add"],
Cell[1144, 37, 1234, 20, 168, "Text",ExpressionUUID->"2e7f8c0e-0e2f-4746-bf91-b282388e0bbe"],
Cell[2381, 59, 666, 14, 76, "Text",ExpressionUUID->"2f2ac88a-1ab0-4f6c-ac9e-3391e980f0dd"],
Cell[3050, 75, 3526, 91, 304, "Input",ExpressionUUID->"f4819cb5-e1db-48c7-bd65-1da7c511f104"],
Cell[6579, 168, 572, 10, 53, "Text",ExpressionUUID->"3472557a-e183-495a-a1e0-a1748157f5fe"],
Cell[7154, 180, 1696, 44, 115, "Input",ExpressionUUID->"96ce5dec-ee45-4af3-adb1-ac8f52cfe628"],
Cell[8853, 226, 649, 12, 53, "Text",ExpressionUUID->"becc19cb-91d4-4e47-aad4-f4aed99b14a6"],
Cell[9505, 240, 2820, 69, 220, "Input",ExpressionUUID->"7c2f08df-700d-4397-be46-6ed23336b7c0"],
Cell[12328, 311, 740, 13, 53, "Text",ExpressionUUID->"32372479-3bef-41f2-b7be-afc27e7f748c"],
Cell[CellGroupData[{
Cell[13093, 328, 166, 3, 30, "Input",ExpressionUUID->"b6701cce-d6c0-4fa3-b437-c088f1a8ac90"],
Cell[13262, 333, 561276, 11936, 573, "Output",ExpressionUUID->"d820740f-6b82-4c67-8297-0fd4da007f2a"]
}, Open  ]],
Cell[574553, 12272, 448, 8, 73, "Input",ExpressionUUID->"27215680-0b6f-48a0-a7ea-4c267f407ab0"]
}, Open  ]]
}
]
*)

